@@ -21,11 +21,13 @@
 
 */
 
+#include <config.h>
+
 #include <gtk/gtk.h>
 #include <string.h>
 #include <ctype.h>
 
-#include "gyrus-i18n.h"
+#include "glib/gi18n.h"
 #include "gyrus-main-app.h"
 #include "gyrus-admin.h"
 #include "gyrus-admin-acl.h"
