@@ -35,6 +35,7 @@
 #include "gyrus-main-app.h"
 #include "gyrus-admin.h"
 #include "gyrus-common.h"
+#include "gyrus-admin-private.h"
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-admin-acl.h"
 
@@ -240,7 +241,7 @@ gyrus_admin_mailbox_on_button_quota_apply_clicked (GtkButton *button,
 	else
 		gyrus_common_show_message (NULL, GTK_MESSAGE_ERROR,
 					   _("Unable to change quota. "
-					     "Are you sure do you have the appropiate permissions?"));
+					     "Are you sure do you have the appropriate permissions?"));
 
 	g_free (mailbox_path);
 
@@ -355,7 +356,7 @@ gyrus_admin_mailbox_new (GyrusAdmin *admin, const gchar *mailbox,
 	if (status != GYRUS_IMAP_STATUS_OK) {
 		g_free (msg);
 		*error = g_strdup (_("Unable to create the mailbox. "
-				     "Are you sure do you have the appropiate permissions?"));
+				     "Are you sure do you have the appropriate permissions?"));
 		return FALSE;
 	}
 
@@ -448,8 +449,7 @@ gyrus_admin_mailbox_delete_all (GyrusAdmin *admin,
 		if (!gyrus_admin_acl_set_entry (admin, (gchar *)iter->data,
 						user, "+d", &error)) {
 			gyrus_common_show_message
-				(GTK_WINDOW (admin->priv->parent_app),
-				 GTK_MESSAGE_ERROR, error);
+				(NULL, GTK_MESSAGE_ERROR, error);
 			g_free (error);
 		}
 
@@ -458,8 +458,7 @@ gyrus_admin_mailbox_delete_all (GyrusAdmin *admin,
 		if (!gyrus_admin_mailbox_delete (admin, (gchar *)iter->data,
 						 &error)) {
 			gyrus_common_show_message
-				(GTK_WINDOW (admin->priv->parent_app),
-				 GTK_MESSAGE_ERROR, error);
+				(NULL, GTK_MESSAGE_ERROR, error);
 			g_free (error);
 		}
 	}
@@ -579,8 +578,7 @@ gyrus_admin_delete_selected_acl_entry (GyrusAdmin *admin)
 		
 	} else {
 		gyrus_common_show_message
-			(GTK_WINDOW (admin->priv->parent_app),
-			 GTK_MESSAGE_ERROR, error);
+			(NULL, GTK_MESSAGE_ERROR, error);
 		g_free (error);
 	}
 
