@@ -43,15 +43,22 @@ gyrus_common_show_message (GtkWindow *parent,
 }
 
 gboolean
-gtk_entry_has_text (GtkEntry *entry)
+gyrus_gtk_entry_has_text (GtkEntry *entry)
 {
-	gboolean has_text;
-	g_return_val_if_fail (entry != NULL, FALSE);
 	g_return_val_if_fail (GTK_IS_ENTRY (entry), FALSE);
 
-	gchar *text = g_strdup (gtk_entry_get_text (entry));
-	has_text = strlen (g_strstrip (text)) > 0;
-	g_free (text);
+	const gchar *text;
+        const gchar *start;
+        gboolean has_text;
+
+        text = gtk_entry_get_text (entry);
+
+        start = text;
+        while (*start != '\0' && g_ascii_isspace (*start))
+                start ++;
+
+        has_text = (start && start[0]);
+
 	return (has_text);
 }
 
