@@ -24,20 +24,30 @@
 #include <config.h>
 
 #include <gnet.h>
+#ifdef HAVE_GNUTLS
 #include <gnutls/gnutls.h>
+#endif
 #include <string.h>
 
 #include "gyrus-connection.h"
 #include "gyrus-marshal.h"
 
 #define COMMAND_ID "GyrusCommand"
+#define MAX_BUFFER_SIZE 8192
+
+#define GYRUS_CONNECTION_GET_PRIVATE(object)         \
+	(G_TYPE_INSTANCE_GET_PRIVATE ((object), GYRUS_TYPE_CONNECTION, GyrusConnectionPrivate))
+
+G_DEFINE_TYPE (GyrusConnection, gyrus_connection, G_TYPE_OBJECT)
 
 struct _GyrusConnectionPrivate {
 	GConn *gconn;
 	GInetAddrNewAsyncID addr_id;
+#ifdef HAVE_GNUTLS
 	gnutls_session *session;
 	/* TRUE while TLS is handshaking */
 	gboolean handshaking;
+#endif
 	/* Data received */
 	gchar *data;
 	gsize data_length;
@@ -75,8 +85,6 @@ enum {
 /* Private API Prototypes */
 
 /* Fields */
-static GObject *parent_class = NULL;
-
 static guint signals[LAST_SIGNAL] = { 0 };
 
 /*** Private API ***/
@@ -92,6 +100,7 @@ gyrus_connection_receive (GyrusConnection *conn)
 /* This callback is called for Decode data.
  * buffer: a buffer to copy the first "size" bytes.
  */
+#ifdef HAVE_GNUTLS
 gssize
 gyrus_connection_tls_read (GyrusConnection *conn,
                            gchar *buffer, gsize size)
@@ -188,6 +197,7 @@ gyrus_connection_tls_write (GyrusConnection *conn,
 
 	return size;
 }
+#endif
 
 /* Writes in conn->priv->ubuffer the data to 
    send to the application, without the COMMAND_ID
@@ -266,6 +276,7 @@ gyrus_connection_conn_cb (GConn *gconn, GConnEvent *event, gpointer data)
 		}
 		case GNET_CONN_CONNECT:
 		{
+#ifdef HAVE_GNUTLS
 			if (conn->priv->tls)
 			{
 				gint priority [] = {GNUTLS_KX_RSA, 0};
@@ -322,6 +333,7 @@ gyrus_connection_conn_cb (GConn *gconn, GConnEvent *event, gpointer data)
 					conn->priv->handshaking = FALSE;
 				}
 			}
+#endif
 		
 			conn->priv->connected = TRUE;
 			
@@ -349,7 +361,8 @@ gyrus_connection_conn_cb (GConn *gconn, GConnEvent *event, gpointer data)
 		case GNET_CONN_READ:
 		{
 			conn->priv->data_length = event->length;
-			
+
+#ifdef HAVE_GNUTLS
 			/* If the connection uses a TLS session, then decode
 			 * received data.
 			 */
@@ -358,14 +371,18 @@ gyrus_connection_conn_cb (GConn *gconn, GConnEvent *event, gpointer data)
 				conn->priv->data = g_memdup (event->buffer, event->length);
 				g_print ("size: %i\n", event->length);
 				/* A dynamic buffer */
-				gchar *buf = (gchar *) g_malloc0 (event->length);
+				gchar *buf = (gchar *) g_malloc0 (MAX_BUFFER_SIZE);
 				gssize len;
-			
-				do {
-					len = gnutls_record_recv (*(conn->priv->session),
-								  buf, event->length);
-				} while ((len == GNUTLS_E_AGAIN) || (len == GNUTLS_E_INTERRUPTED));
-
+				
+				len = gnutls_record_recv (*(conn->priv->session),
+							  buf, MAX_BUFFER_SIZE);
+				
+				if ((len == GNUTLS_E_AGAIN) || (len == GNUTLS_E_INTERRUPTED)) {
+					/* The gnutls decoder needs more data to finish decoding. */
+					gyrus_connection_receive (conn);
+					return;
+				}
+				
 /*				g_free (conn->priv->data); */
 
 				if (len < 0)
@@ -388,6 +405,7 @@ gyrus_connection_conn_cb (GConn *gconn, GConnEvent *event, gpointer data)
 				g_free (buf);
 			}
 			else
+#endif
 			{
 				conn->priv->data = g_strndup (event->buffer, event->length);
 			}
@@ -485,32 +503,32 @@ static void
 gyrus_connection_set_property (GObject *object,
 			       guint property_id, const GValue *value, GParamSpec *pspec)
 {
-	GyrusConnection *conn = GYRUS_CONNECTION (object);
-
+	GyrusConnectionPrivate *priv = GYRUS_CONNECTION_GET_PRIVATE (object);
+	
 	switch (property_id)
 	{
 		case PROP_HOST:
 		{
-			g_free (conn->priv->host);
-			conn->priv->host = g_value_dup_string (value);
+			g_free (priv->host);
+			priv->host = g_value_dup_string (value);
 			break;
 		}
 
 		case PROP_PORT:
 		{
-			conn->priv->port = g_value_get_int (value);
+			priv->port = g_value_get_int (value);
 			break;
 		}
 
 		case PROP_CONNECTED:
 		{
-			conn->priv->connected = g_value_get_boolean (value);
+			priv->connected = g_value_get_boolean (value);
 			break;
 		}
 
 		case PROP_TLS:
 		{
-			conn->priv->tls = g_value_get_boolean (value);
+			priv->tls = g_value_get_boolean (value);
 			break;
 		}
 
@@ -570,7 +588,7 @@ gyrus_connection_class_init (GyrusConnectionClass *klass)
 	GType data_received_param_types[2];
 	GType connect_response_param_types[1];
 	
-	parent_class = g_type_class_peek_parent (klass);
+	gyrus_connection_parent_class = g_type_class_peek_parent (klass);
 
 	gobject_class->set_property = gyrus_connection_set_property;
 	gobject_class->get_property = gyrus_connection_get_property;
@@ -637,7 +655,7 @@ gyrus_connection_class_init (GyrusConnectionClass *klass)
 		               G_TYPE_FROM_CLASS (klass),
 			       G_SIGNAL_RUN_LAST | G_SIGNAL_NO_RECURSE | G_SIGNAL_NO_HOOKS,
 			       NULL, NULL, NULL,
-			       g_cclosure_marshal_VOID__ENUM,
+			       g_cclosure_marshal_VOID__INT,
 			       G_TYPE_NONE, 1,
 			       connect_response_param_types);
 	
@@ -648,16 +666,20 @@ gyrus_connection_class_init (GyrusConnectionClass *klass)
 			       NULL, NULL, NULL,
 			       g_cclosure_marshal_VOID__VOID,
 			       G_TYPE_NONE, 0, NULL);
+
+	g_type_class_add_private (klass, sizeof (GyrusConnectionPrivate));
 }
 
 static void
-gyrus_connection_instance_init (GyrusConnection *conn)
+gyrus_connection_init (GyrusConnection *conn)
 {
-	conn->priv = g_new0 (GyrusConnectionPrivate, 1);
+	conn->priv = GYRUS_CONNECTION_GET_PRIVATE (conn);
 	
 	conn->priv->gconn = NULL;
+#ifdef HAVE_GNUTLS
 	conn->priv->session = NULL;
 	conn->priv->handshaking = TRUE;
+#endif
 	conn->priv->data = NULL;
 	/* Crate the buffer for the request results */
 	conn->priv->buffer = g_string_new ("");
@@ -667,34 +689,6 @@ gyrus_connection_instance_init (GyrusConnection *conn)
 }
 
 /*** Public API ***/
-
-GType
-gyrus_connection_get_type (void)
-{
-	static GType type = 0;
-
-	if (!type) {
-		static const GTypeInfo info = {
-			sizeof (GyrusConnectionClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) gyrus_connection_class_init,
-			NULL, /* class_finalize */
-			NULL, /* class_data */
-			sizeof (GyrusConnection),
-			0,    /* n_preallocs */
-			(GInstanceInitFunc) gyrus_connection_instance_init,
-			0
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-		                               "GyrusConnection",
-					       &info, 0);
-	}
-
-	return type;
-}
-
 GyrusConnection *
 gyrus_connection_new (gchar *host, gint port, gboolean use_tls)
 {
@@ -718,18 +712,21 @@ gyrus_connection_destroy (GyrusConnection *conn)
 void
 gyrus_connection_connect (GyrusConnection *conn)
 {
+#ifdef HAVE_GNUTLS	
 	static gboolean gnutls_initialized = FALSE;
-	
+#endif
 	g_return_if_fail (GYRUS_IS_CONNECTION (conn));
 
 	if (gyrus_connection_get_connected (conn) == TRUE)
 		return;
 
+#ifdef HAVE_GNUTLS	
 	if (!gnutls_initialized)
 	{
 		gnutls_global_init ();
 		gnutls_initialized = TRUE;
 	}
+#endif
 
 	conn->priv->addr_id = gnet_inetaddr_new_async (
 			gyrus_connection_get_host (conn),
@@ -763,9 +760,11 @@ gyrus_connection_send (GyrusConnection *conn, const gchar *buffer)
 	
 	g_print ("Sending command <%s> %d bytes\n", cmd->str, cmd->len);
 
+#ifdef HAVE_GNUTLS
 	if (conn->priv->tls)
 		gnutls_record_send (*(conn->priv->session), cmd->str, cmd->len);
 	else
+#endif
 		gnet_conn_write (conn->priv->gconn, cmd->str, cmd->len);
 }
 
