@@ -38,15 +38,23 @@
 #include "gyrus-admin-mailbox.h"
 #include "gyrus-report.h"
 
-static void gyrus_main_app_class_init (GyrusMainAppClass *class);
-static void gyrus_main_app_init (GyrusMainApp *app);
-static void gyrus_main_app_finalize (GObject *object);
-static void gyrus_main_app_destroy (GtkObject *object);
+#define GYRUS_MAIN_APP_GET_PRIVATE(object)         \
+	G_TYPE_INSTANCE_GET_PRIVATE (object, GYRUS_TYPE_MAIN_APP, GyrusMainAppPrivate);
+
+G_DEFINE_TYPE (GyrusMainApp, gyrus_main_app, GTK_TYPE_WINDOW)
+
+/*** Gyrus Main Application Private Data ***/
+struct _GyrusMainAppPrivate {
+        GtkWidget *notebook;
+        GtkUIManager *ui_manager;
+        GtkActionGroup *actions_window;
+        GtkActionGroup *actions_server;
+        GtkActionGroup *actions_mailbox;
+        GtkActionGroup *actions_acl_item;
+};
 
 static void gyrus_main_app_about (void);
 
-static GtkWindowClass *parent_class = NULL;
-
 /*** Class Callbacks ***/
 
 static void
@@ -286,29 +294,27 @@ gyrus_main_app_on_switch_page (GtkNotebook *notebook,
 
 /*** Private Methods ***/
 
-GType
-gyrus_main_app_get_type (void)
+static void
+gyrus_main_app_finalize (GObject *object)
 {
-	static GType type = 0;
-  
-	if (!type) {
-		static const GTypeInfo info = {
-				sizeof (GyrusMainAppClass),
-				NULL,           /* base_init */
-				NULL,           /* base_finalize */
-				(GClassInitFunc) gyrus_main_app_class_init,
-				NULL,           /* class_finalize */
-				NULL,           /* class_data */
-				sizeof (GyrusMainApp),
-				0,              /* n_preallocs */
-				(GInstanceInitFunc) gyrus_main_app_init,
-				0
-		};
-		type = g_type_register_static (GTK_TYPE_WINDOW,
-					       "GyrusMainApp",
-					       &info, 0);
-	}
-	return type;
+	GyrusMainApp *app;
+
+	g_return_if_fail (GYRUS_IS_MAIN_APP(object));
+
+	app = GYRUS_MAIN_APP (object);
+
+	G_OBJECT_CLASS (gyrus_main_app_parent_class)->finalize (object);
+}
+
+static void
+gyrus_main_app_destroy (GtkObject *object)
+{
+	GyrusMainApp *app;
+	g_return_if_fail (GYRUS_IS_MAIN_APP (object));
+	app = GYRUS_MAIN_APP (object);
+
+	GTK_OBJECT_CLASS (gyrus_main_app_parent_class)->destroy (object);
+
 }
 
 static void
@@ -317,10 +323,13 @@ gyrus_main_app_class_init (GyrusMainAppClass *class)
 	GObjectClass *gobject_class = G_OBJECT_CLASS (class);
 	GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
 
-	parent_class = g_type_class_peek_parent (class);
+	gyrus_main_app_parent_class = g_type_class_peek_parent (class);
 
 	gobject_class->finalize = gyrus_main_app_finalize;
 	object_class->destroy = gyrus_main_app_destroy;
+
+	/* register private struct */
+	g_type_class_add_private (class, sizeof(GyrusMainAppPrivate));
 }
 
 static const char *ui_description =
@@ -365,17 +374,17 @@ static const char *ui_description =
 "</ui>\n";
 
 static const GtkActionEntry entries_window[] = {
-  { "FileMenu", NULL, N_("_File") },
-  { "EditMenu", NULL, N_("_Edit") },
-  { "AclMenu", NULL, N_("_ACL") },
-  { "ViewMenu", NULL, N_("_View") },
-  { "HelpMenu", NULL, N_("_Help") },
-  { "OpenSession", GTK_STOCK_OPEN, N_("Go to server..."), "<control>O", 
-    N_("Show the list of servers"), G_CALLBACK (gyrus_main_app_on_file_open_session) },
-  { "Quit", GTK_STOCK_QUIT, N_("_Quit"), "<control>Q", 
-    N_("Quit the program"), G_CALLBACK (gyrus_main_app_on_file_exit) },
-  { "About", GTK_STOCK_ABOUT, N_("_About"), NULL, 
-    NULL, G_CALLBACK (gyrus_main_app_on_help_about) }
+	{ "FileMenu", NULL, N_("_File") },
+	{ "EditMenu", NULL, N_("_Edit") },
+	{ "AclMenu", NULL, N_("_ACL") },
+	{ "ViewMenu", NULL, N_("_View") },
+	{ "HelpMenu", NULL, N_("_Help") },
+	{ "OpenSession", GTK_STOCK_OPEN, N_("Go to server..."), "<control>O", 
+	  N_("Show the list of servers"), G_CALLBACK (gyrus_main_app_on_file_open_session) },
+	{ "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL,
+	  G_CALLBACK (gyrus_main_app_on_file_exit) },
+	{ "About", GTK_STOCK_ABOUT, NULL, NULL, NULL, 
+	  G_CALLBACK (gyrus_main_app_on_help_about) }
 /*  { "Preferences", GTK_STOCK_PREFERENCES, N_("_Preferences"), NULL, 
     N_("Show the program preferences"), gyrus_main_app_on_edit_preferences } */
 };
@@ -383,11 +392,11 @@ static const GtkActionEntry entries_window[] = {
 static const GtkActionEntry entries_server[] = {
   { "AddMailbox", GTK_STOCK_ADD, N_("Add mailbox"), NULL,
     N_("Add a mailbox under the one selected"), G_CALLBACK (gyrus_main_app_on_edit_mailbox_add) },
-  { "Find", GTK_STOCK_FIND, N_("_Find"), "<control>F", 
+  { "Find", GTK_STOCK_FIND, NULL, NULL, 
     N_("Search for a mailbox in current server"), G_CALLBACK (gyrus_main_app_on_edit_find) },
-  { "Refresh", GTK_STOCK_REFRESH, N_("_Refresh"), "<control>R", 
+  { "Refresh", GTK_STOCK_REFRESH, NULL, "<control>R", 
     N_("Refresh the mailbox list"), G_CALLBACK (gyrus_main_app_on_view_refresh) },
-  { "Report", NULL, N_("Report"), NULL, 
+  { "Report", NULL, N_("Create report..."), NULL, 
     N_("Create report of users with quota problems"), G_CALLBACK (gyrus_main_app_on_view_report) }
 };
 
@@ -417,7 +426,9 @@ gyrus_main_app_init (GyrusMainApp *app)
 	GtkAccelGroup *accel_group;
 	GError *error;
 
-	app->priv = g_new0 (GyrusMainAppPrivate, 1);
+	/* get a private struct */
+	app->priv = GYRUS_MAIN_APP_GET_PRIVATE (app);
+
 	gtk_window_set_title (GTK_WINDOW (app),
 			      _("Cyrus IMAP Administrator"));
 
@@ -490,31 +501,6 @@ gyrus_main_app_init (GyrusMainApp *app)
 	gtk_widget_show_all (main_vbox);
 }
 
-static void
-gyrus_main_app_finalize (GObject *object)
-{
-	GyrusMainApp *app;
-
-	g_return_if_fail (GYRUS_IS_MAIN_APP(object));
-
-	app = GYRUS_MAIN_APP (object);
-
-	g_free (app->priv);
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-static void
-gyrus_main_app_destroy (GtkObject *object)
-{
-	GyrusMainApp *app;
-	g_return_if_fail (GYRUS_IS_MAIN_APP (object));
-	app = GYRUS_MAIN_APP (object);
-
-	GTK_OBJECT_CLASS (parent_class)->destroy (object);
-
-}
-
 GyrusAdmin *
 gyrus_main_app_get_current_admin (GyrusMainApp *app)
 {
@@ -561,6 +547,7 @@ gyrus_main_app_about (void)
 			       "authors", authors, 
 			       "translator-credits", strcmp (translators, "translators-credits") != 0 ? translators : NULL,
 			       "logo", pixbuf,
+			       "website", "http://www.gnome.org/projects/gyrus",
 			       NULL);
 
 	g_object_unref(pixbuf);
@@ -632,9 +619,9 @@ main_app_on_admin_disconnected (GyrusAdmin *admin,
 }
 
 static void
-main_app_on_acl_entry_selection_changed (GyrusAdmin *admin,
-					 gboolean selected,
-					 gpointer *data)
+main_app_on_acl_selection_changed (GyrusAdmin *admin,
+				   gboolean selected,
+				   gpointer *data)
 {
 	GyrusMainApp *app = GYRUS_MAIN_APP (data);
 	gtk_action_group_set_sensitive (app->priv->actions_acl_item,
@@ -667,17 +654,14 @@ gyrus_main_app_append_page (GyrusMainApp *app, GyrusSession *session)
 			  G_CALLBACK (main_app_on_admin_disconnected), 
 			  app);
 	
-	g_signal_connect (G_OBJECT (admin), "acl-entry-selection-changed", 
-			  G_CALLBACK (main_app_on_acl_entry_selection_changed), 
+	g_signal_connect (G_OBJECT (admin), "acl-selection-changed", 
+			  G_CALLBACK (main_app_on_acl_selection_changed), 
 			  app);
 
 	g_signal_connect (G_OBJECT (admin), "mailbox-selection-changed", 
 			  G_CALLBACK (main_app_on_mailbox_selection_changed), 
 			  app);
 	
-	gyrus_admin_set_parent_app (GYRUS_ADMIN (admin),
-				    (gpointer) app);
-	
 	gtk_notebook_append_page (GTK_NOTEBOOK (app->priv->notebook),
 				  admin, NULL);
 	
