@@ -21,9 +21,11 @@
   
 */
 
+#include <config.h>
+
 #include <glade/glade.h>
 
-#include "gyrus-i18n.h"
+#include "glib/gi18n.h"
 #include "gyrus-preferences.h"
 
 void
