@@ -239,6 +239,7 @@ gyrus_report_on_button_update_clicked (GtkWidget *widget,
 {
 	GtkListStore *store;
         GtkTreeViewColumn *column;
+	GtkTreeView *treeview;
         gint n_users;
         gchar *msg;
 	GyrusAdmin *admin;
@@ -253,7 +254,8 @@ gyrus_report_on_button_update_clicked (GtkWidget *widget,
 	gtk_list_store_clear (store);
 		
 	/* get model of treeview users */
-	GtkTreeModel *model = gtk_tree_view_get_model (admin->priv->treeview_users);
+	treeview = gyrus_admin_get_users_treeview (admin);
+	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
 
 	/* for each user */
 	gtk_tree_model_foreach (model, gyrus_report_evaluate_quota, report);
@@ -274,6 +276,7 @@ gyrus_report_on_button_update_clicked (GtkWidget *widget,
 	}
         
 	g_free (msg);
+	g_object_unref (treeview);
 }
 
 /* evaluate percentage */
