@@ -62,7 +62,6 @@ static void gyrus_session_edit_session (GyrusSession *session);
 static void gyrus_session_append_session (GyrusSession *session);
 gboolean gyrus_session_name_is_valid (GyrusSession *session);
 gboolean gyrus_session_is_valid (GyrusSession *session, gchar **why_invalid);
-inline int gyrus_session_name_compare_func (gconstpointer a, gconstpointer b);
 static void gyrus_session_select_session (GyrusSession *session);
 
 static GConfClient *conf_client;
@@ -191,15 +190,6 @@ gyrus_session_on_button_open_clicked (GtkWidget *widget,
 	gyrus_session_free (session);
 }
 
-inline int
-gyrus_session_name_compare_func (gconstpointer a,
-				 gconstpointer b)
-{
-	return g_ascii_strcasecmp ((const gchar *)a,
-				   (const gchar *)b);
-}
-		
-
 void
 gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 						gpointer user_data)
@@ -211,7 +201,7 @@ gyrus_session_on_button_delete_session_clicked (GtkWidget *widget,
 						  GCONF_VALUE_STRING, NULL);
 
 	GSList *element = g_slist_find_custom (sessions, session->name,
-					       gyrus_session_name_compare_func);
+					       (GCompareFunc) g_ascii_strcasecmp);
 	if (element) {
 		g_free (element->data);
 		sessions = g_slist_delete_link (sessions, element);
@@ -256,6 +246,17 @@ gyrus_session_on_button_cancel_clicked (GtkWidget *widget, gpointer user_data)
 	gtk_widget_destroy (window);
 }
 
+void
+gyrus_session_on_row_activated (GtkTreeView       *tree_view,
+				GtkTreePath       *path,
+				GtkTreeViewColumn *column,
+				gpointer           user_data)
+{
+	GyrusSession *session = gyrus_session_get_selected_session (FALSE);
+	gyrus_session_open (session, user_data);
+	gyrus_session_free (session);	
+}
+
 void
 gyrus_session_list_set_sensitive (gboolean sensitive)
 {
@@ -264,6 +265,21 @@ gyrus_session_list_set_sensitive (gboolean sensitive)
 	gtk_widget_set_sensitive (button_properties, sensitive);
 }
 
+void
+gyrus_session_on_entry_changed (GtkEditable *editable,
+				gpointer user_data)
+{
+	GtkWidget *widget = GTK_WIDGET (user_data);
+	
+	gboolean sensitive = 
+		gyrus_gtk_entry_has_text (GTK_ENTRY (entry_name)) &&
+		gyrus_gtk_entry_has_text (GTK_ENTRY (entry_host)) &&
+/* 		gyrus_gtk_entry_has_text (GTK_ENTRY (entry_passwd) && */
+		gyrus_gtk_entry_has_text (GTK_ENTRY (entry_user));
+
+	gtk_widget_set_sensitive (widget, sensitive);
+}
+
 /* save changes in @session in gconf */
 static void
 gyrus_session_edit_session (GyrusSession *session)
@@ -347,7 +363,7 @@ gyrus_session_append_session (GyrusSession *new)
 						  GCONF_VALUE_STRING, NULL);
 
 	GSList * element = g_slist_find_custom (sessions, new->name,
-						gyrus_session_name_compare_func);
+						(GCompareFunc) g_ascii_strcasecmp);
 	if (element) {
 		gchar * msg = g_strdup_printf (_("Session named \"%s\" already exists."),
 					       new->name);
@@ -386,8 +402,6 @@ gyrus_session_append_session (GyrusSession *new)
 	g_free (usetls);
 	
 	gyrus_session_load_gconf_settings();
-	gyrus_common_show_message (GTK_WINDOW (window), GTK_MESSAGE_INFO,
-				   _("Session saved"));
 }
 
 static void
@@ -458,7 +472,7 @@ gyrus_session_new_from_interface (void)
 	return session;
 }
 
-/* adds a session in the list and in the treeview */
+/* adds a session to the list and to the treeview */
 static void
 gyrus_session_add_session_to_treeview (GyrusSession *session)
 {
@@ -503,11 +517,6 @@ gyrus_session_treeview_on_key_press_event (GtkWidget *widget,
 	case GDK_Delete:
 		gtk_button_clicked (GTK_BUTTON (button_delete));
 		return TRUE;
-		break;
-	case GDK_Return:
-	case GDK_KP_Enter:
-		gtk_button_clicked (GTK_BUTTON (button_open));
-		return TRUE;
 	}
 	
 	return FALSE;
@@ -518,7 +527,7 @@ gyrus_session_on_key_press_event (GtkWidget *widget,
 				  GdkEventKey *event,
 				  gpointer user_data)
 {
-	/* i've used a switch/case here because i am thinking in possible next
+	/* I've used a switch/case here because I am thinking in possible future
 	 key events */
 	
 	switch (event->keyval) {
@@ -573,11 +582,11 @@ gyrus_session_create_model_sessions (void)
 	model_sessions = GTK_TREE_MODEL (model);
 }
 
-/* If remove is TRUE, the select item is remove from the array */
+/* If remove is TRUE, the selected item is removed from the array */
 GyrusSession *
 gyrus_session_get_selected_session (gboolean remove)
 {
-GtkTreeIter iter;
+	GtkTreeIter iter;
 	GtkTreeSelection *selection;
 
 	GyrusSession *session = g_new0 (GyrusSession, 1);
@@ -684,15 +693,14 @@ gyrus_session_open (GyrusSession *session, gpointer user_data)
 	g_return_if_fail (GYRUS_IS_MAIN_APP (user_data));
 
 	GyrusMainApp *app = GYRUS_MAIN_APP (user_data);
-	GtkWidget *new_admin;
-	
+
 	if (!session->host || !strlen (session->host)) {
 		gyrus_common_show_message(GTK_WINDOW (window),
 					  GTK_MESSAGE_ERROR,
 					  _("No host specified."));
 		return;
 	}
-	new_admin = gyrus_main_app_append_page (GYRUS_MAIN_APP (app), session);
+	gyrus_main_app_append_page (GYRUS_MAIN_APP (app), session);
 	gtk_widget_destroy (GTK_WIDGET (window));
 }
 
@@ -745,6 +753,10 @@ gyrus_session_load_interface (gpointer user_data)
 			  G_CALLBACK (gyrus_session_on_key_press_event),
 			  NULL);
 
+	g_signal_connect (G_OBJECT (treeview_sessions), "row-activated", 
+			  G_CALLBACK (gyrus_session_on_row_activated), 
+			  user_data);
+
 	gyrus_session_set_treeview ();
 	gyrus_session_list_set_sensitive (FALSE);
 	gyrus_session_create_model_sessions ();
@@ -781,6 +793,24 @@ gyrus_session_edit_load_interface (gpointer user_data)
 	                  G_CALLBACK (gyrus_session_checkbutton_secure_toggled),
 	                  (gpointer) spinbutton_port);
 	
+	g_signal_connect (G_OBJECT (entry_host), "changed",
+			  G_CALLBACK (gyrus_session_on_entry_changed),
+			  button_session_edit_ok);
+
+	g_signal_connect (G_OBJECT (entry_user), "changed",
+			  G_CALLBACK (gyrus_session_on_entry_changed),
+			  button_session_edit_ok);
+
+	g_signal_connect (G_OBJECT (entry_passwd), "changed",
+			  G_CALLBACK (gyrus_session_on_entry_changed),
+			  button_session_edit_ok);
+
+	g_signal_connect (G_OBJECT (entry_name), "changed",
+			  G_CALLBACK (gyrus_session_on_entry_changed),
+			  button_session_edit_ok);
+
+	gtk_widget_set_sensitive (button_session_edit_ok, FALSE);
+
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combobox_sep_char), 0);
 
 	gtk_window_set_modal (GTK_WINDOW (window_edit), TRUE);
